==> supplier-center-api-1.2.13-20231109.023516-2-sources.jar: cn/com/duiba/supplier/center/api/dto/supplier/SupplyOrderRetryDto.java <==
package cn.com.duiba.supplier.center.api.dto.supplier;

import java.util.Date;

public class SupplyOrderRetryDto {


    /**
     * 主键id
     */
    private Long id;

    /**
     * 三方订单号
     */
    private String thirdOrderNum;

    /**
     * 采购请求信息
     */
    private String supplyRequestInfo;

    /**
     * 兑吧appId
     */
    private String appId;

    /**
     * 是否删除：0-未删除，1-已删除
     */
    private Integer deleted;

    /**
     * 额外信息
     */
    private String extra;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getThirdOrderNum() {
        return thirdOrderNum;
    }

    public void setThirdOrderNum(String thirdOrderNum) {
        this.thirdOrderNum = thirdOrderNum;
    }

    public String getSupplyRequestInfo() {
        return supplyRequestInfo;
    }

    public void setSupplyRequestInfo(String supplyRequestInfo) {
        this.supplyRequestInfo = supplyRequestInfo;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}

==> supplier-center-api-2.1.54-20251107.093206-1-sources.jar: cn/com/duiba/supplier/center/api/dto/supplier/SupplyOrderRetryDto.java <==
package cn.com.duiba.supplier.center.api.dto.supplier;

import java.io.Serializable;
import java.util.Date;

public class SupplyOrderRetryDto implements Serializable {


    private static final long serialVersionUID = -4679306254185402800L;
    /**
     * 主键id
     */
    private Long id;

    /**
     * 三方订单号
     */
    private String thirdOrderNum;

    /**
     * 采购请求信息
     */
    private String supplyRequestInfo;

    /**
     * 兑吧appId
     */
    private Long appId;

    /**
     * 是否删除：0-未删除，1-已删除
     */
    private Integer deleted;

    /**
     * 额外信息
     */
    private String extra;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getThirdOrderNum() {
        return thirdOrderNum;
    }

    public void setThirdOrderNum(String thirdOrderNum) {
        this.thirdOrderNum = thirdOrderNum;
    }

    public String getSupplyRequestInfo() {
        return supplyRequestInfo;
    }

    public void setSupplyRequestInfo(String supplyRequestInfo) {
        this.supplyRequestInfo = supplyRequestInfo;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}
